Model Reference
===============

This page is a reference to all the models in the Python SDK. It exists on a seperate page to not clutter the main API reference.

.. currentmodule:: autumn

Balance
-------

.. autoclass:: autumn.models.balance.Balance
   :members:
   :undoc-members:

Customer models
---------------

.. autoclass:: autumn.models.customers.ProductStatus
   :members:
   :undoc-members:

.. autoclass:: autumn.models.customers.FeatureType
   :members:
   :undoc-members:

.. autoclass:: autumn.models.customers.CustomerInvoice
   :members:
   :undoc-members:

.. autoclass:: autumn.models.customers.CustomerFeature
   :members:
   :undoc-members:

.. autoclass:: autumn.models.customers.CustomerProduct
   :members:
   :undoc-members:

.. autoclass:: autumn.models.customers.Customer
   :members:
   :undoc-members:

.. autoclass:: autumn.models.customers.PriceInfo
   :members:
   :undoc-members:

.. autoclass:: autumn.models.customers.ItemInfo
   :members:
   :undoc-members:

.. autoclass:: autumn.models.customers.ProductStatus
   :members:
   :undoc-members:

.. autoclass:: autumn.models.customers.GetPricingTableParams
   :members:
   :undoc-members:

.. autoclass:: autumn.models.customers.PricingTableProduct
   :members:
   :undoc-members:

Feature models
--------------

.. autoclass:: autumn.models.features.Feature
   :members:
   :undoc-members:

.. autoclass:: autumn.models.features.FeaturePreview
   :members:
   :undoc-members:

Product models
--------------

.. autoclass:: autumn.models.products.FreeTrialDuration
   :members:
   :undoc-members:

.. autoclass:: autumn.models.products.UsageModel
   :members:
   :undoc-members:

.. autoclass:: autumn.models.products.ProductItemInterval
   :members:
   :undoc-members:

.. autoclass:: autumn.models.products.PriceCurrencyPair
   :members:
   :undoc-members:

.. autoclass:: autumn.models.products.PriceTier
   :members:
   :undoc-members:

.. autoclass:: autumn.models.products.ProductItem
   :members:
   :undoc-members:

.. autoclass:: autumn.models.products.FreeTrialDuration
   :members:
   :undoc-members:

.. autoclass:: autumn.models.products.FreeTrial
   :members:
   :undoc-members:

.. autoclass:: autumn.models.products.ProductScenario
   :members:
   :undoc-members:

.. autoclass:: autumn.models.products.Product
   :members:
   :undoc-members:

.. autoclass:: autumn.models.products.ProductPreview
   :members:
   :undoc-members:

Entity models
--------

.. autoclass:: autumn.models.entities.Entity
   :members:
   :undoc-members:

Environment
-----------

.. autoclass:: autumn.models.env.AppEnv
   :members:
   :undoc-members:

Response models
---------------

.. autoclass:: autumn.models.response.AttachResponse
   :members:
   :undoc-members:

.. autoclass:: autumn.models.response.CheckResponse
   :members:
   :undoc-members:

.. autoclass:: autumn.models.response.TrackResponse
   :members:
   :undoc-members:

.. autoclass:: autumn.models.response.UsageResponse
   :members:
   :undoc-members:

.. autoclass:: autumn.models.response.BillingProductResponse
   :members:
   :undoc-members:

.. autoclass:: autumn.models.response.CreateProductResponse
   :members:
   :undoc-members:

.. autoclass:: autumn.models.response.GetProductResponse
   :members:
   :undoc-members:

.. autoclass:: autumn.models.response.ReferralCodeResponse
   :members:
   :undoc-members:

.. autoclass:: autumn.models.response.CancelResponse
   :members:
   :undoc-members:

.. autoclass:: autumn.models.response.PricingTableResponse
   :members:
   :undoc-members:

.. autoclass:: autumn.models.response.CheckoutLine
   :members:
   :undoc-members:

.. autoclass:: autumn.models.response.CheckoutNextCycle
   :members:
   :undoc-members:

.. autoclass:: autumn.models.response.CheckoutResponse
   :members:
   :undoc-members:

.. autoclass:: autumn.models.response.ListProductResponse
   :members:
   :undoc-members:

.. autoclass:: autumn.models.response.ListCustomerResponse
   :members:
   :undoc-members:

.. autoclass:: autumn.models.response.QueryResponse
   :members:
   :undoc-members:

.. autoclass:: autumn.models.response.TransferProductResponse
   :members:
   :undoc-members:

Meta models
-----------

.. autoclass:: autumn.models.meta.Empty
   :members:
   :undoc-members:

.. autoclass:: autumn.models.meta.FeatureOptions
   :members:
   :undoc-members:

.. autoclass:: autumn.models.meta.ProductOptions
   :members:
   :undoc-members:

.. autoclass:: autumn.models.meta.CustomerData
   :members:
   :undoc-members:

.. autoclass:: autumn.models.meta.AttachProductOptions
   :members:
   :undoc-members:

.. autoclass:: autumn.models.meta.CheckoutLine
   :members:
   :undoc-members:

.. autoclass:: autumn.models.meta.Cycle
   :members:
   :undoc-members:

.. autoclass:: autumn.models.meta.QueryDP
   :members:
   :undoc-members: